import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';
import { useNavigate } from 'react-router-dom';


const AddCustomer = () => {
  const navigate = useNavigate();
  const [customerData, setCustomerData] = useState({
    name: '',
    age: '',
    gender: '',
    email: '',
    address: '',
    mobile: '',
  });

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCustomerData({
      ...customerData,
      [name]: value,
    });
  };

  const handleAddCustomerSubmit = async (e) => {
    e.preventDefault();
    try {
      const response = await axiosInstance.post('http://localhost:5000/customers', customerData);
      navigate('/customers');
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-white">
        <div className="min-h-screen text-gray-300 p-6">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-semibold text-#0e355b">Add Customer</h1>
            <Link to="/" className="text-#0e355b">Skip for now</Link>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div className="space-y-6">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-700 w-24 h-24 rounded-full mx-auto"></div>
                  <button className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-orange-500 text-white text-xs px-2 py-1 rounded-full">
                    {/* Add Customer Image */}
                  </button>
                </div>
              </div>
              <div>
                <Link to="/">
                  <h2 className="text-lg font-semibold text-">Customer Information</h2>
                </Link>
                <Link to="/measurements">
                  <h2 className="text-lg font-semibold text-">Measurements</h2>
                </Link>
              </div>
            </div>
            <div className="md:col-span-2 space-y-4">
              <form onSubmit={handleAddCustomerSubmit}>
                <div>
                  <label className="block text-sm font-medium text-black-700">Customer Name:</label>
                  <input
                    type="text"
                    name="name"
                    value={customerData.name}
                    onChange={handleInputChange}
                    className="input-underline"
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Age:</label>
                  <input
                    type="number"
                    name="age"
                    value={customerData.age}
                    onChange={handleInputChange}
                    className="input-underline"
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Gender:</label>
                  <select
                    name="gender"
                    value={customerData.gender}
                    onChange={handleInputChange}
                    className="input-underline"
                  >
                    <option value="" disabled>Select gender</option>
                    <option value="male">Male</option>
                    <option value="female">Female</option>
                    <option value="other">Other</option>
                  </select>
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Email:</label>
                  <input
                    type="email"
                    name="email"
                    value={customerData.email}
                    onChange={handleInputChange}
                    className="input-underline"
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Address:</label>
                  <input
                    type="text"
                    name="address"
                    value={customerData.address}
                    onChange={handleInputChange}
                    className="input-underline"
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Mobile No:</label>
                  <input
                    type="text"
                    name="mobile"
                    value={customerData.mobile}
                    onChange={handleInputChange}
                    className="input-underline"
                  />
                </div>
                <br />
                <div className="text-center">
                  <button type="submit" className="bg-orange-500 text-black px-4 py-2 rounded-md font-semibold text-sm">
                    Save Information
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddCustomer;
